@@ -14,78 +14,84 @@ Usage:
 Options:
     --hostname=<HOSTNAME>               \
             RabbitMQ Server [default: localhost]
-    --port=<PORT>                       \
-            RabbitMQ Port [default: 5672]
+    --amqp-port=<PORT>                       \
+            RabbitMQ AMQP Port [default: 5672]
+    --api-port=<PORT>                       \
+            RabbitMQ API Port [default: 15672]
     --virtual-host=<VIRTUAL-HOST>       \
             RabbitMQ Virtual Host [default: /]
+    --username=<USERNAME>
+            RabbitMQ API username [default: guest]
+    --password=<PASSWORD>
+            RabbitMQ API password [default: guest]
     --loglevel=(debug | info | warning | error)     [default: warning]
     -h --help                                       Print this help
     --version                                       Print the version
 '''
 
+import base64
 import itertools
 import json
 import logging
 import pickle
-import pika
 import re
+import requests
+import urllib
 
 from celery import Celery
+from collections import namedtuple
 from docopt import docopt
 
 from ._version import __version__
 
 CELERY_QUEUE_NAME = 'celery'
+_API_URL_TEMPLATE = ('http://{host}:{port}'
+                     '/api/queues/{vhost}/{queue}/get')
+_API_MAX_MESSAGE_COUNT = 10000
 
 LOG = logging.getLogger(__name__)
 
+HttpConnectionParams = namedtuple('HttpConnectionParams',
+                                  ['host', 'port', 'vhost', 'queue', 'username', 'password'])
 
-def queued_tasks(mq_channel, queue):
+
+def queued_tasks(http_conn_params):
     """
     Get task ids for all tasks in the specified queue
 
-    :param mq_channel: The pika Channel to use to connect queue
-    :param queue: The queue to read tasks from
+    :param http_conn_params: An instance of HttpConnectionParams
     """
-    amqp_messages = _read_messages_from_amqp(mq_channel, queue)
-    return _extract_task_ids_from_amqp_messages(amqp_messages)
+    url = _API_URL_TEMPLATE.format(
+        host=http_conn_params.host,
+        port=http_conn_params.port,
+        vhost=urllib.quote_plus(http_conn_params.vhost),
+        queue=urllib.quote_plus(http_conn_params.queue))
+
+    post_data = json.dumps({'count': _API_MAX_MESSAGE_COUNT,
+                            'requeue': True,
+                            'encoding': 'base64'})
+    auth = (http_conn_params.username, http_conn_params.password)
+    response = requests.post(url, data=post_data, auth=auth)
+
+    response.raise_for_status()
+
+    return _extract_task_ids_from_messages(response.json())
 
 
-def _read_messages_from_amqp(mq_channel, queue):
-    """ Reads all amqp messages from the queue and requeues them """
-    amqp_messages = []
-    delivery_tags = []
-    try:
-        # Wide try block to ensure no matter what happens in here we put
-        # the messages we've taken back on to the queue
-        while True:
-            # Get tasks off the queue until empty (i.e. None returned)
-            amqp_message = mq_channel.basic_get(queue=queue)
-            method, _header, _body_str = amqp_message
-            if method is None:
-                break
-            delivery_tags.append(method.delivery_tag)
-            amqp_messages.append(amqp_message)
-    finally:
-        for delivery_tag in delivery_tags:
-            # Reject the tasks, therefore putting them back on the queue
-            mq_channel.basic_reject(delivery_tag=delivery_tag)
-
-    return amqp_messages
-
-
-def _extract_task_ids_from_amqp_messages(amqp_messages):
+def _extract_task_ids_from_messages(messages):
     task_ids = []
 
-    for (method, header, body_str) in amqp_messages:
-        if header.content_type == 'application/x-python-serialize':
-            body = pickle.loads(body_str)
-        elif header.content_type == 'application/json':
-            body = json.loads(body_str)
+    for message in messages:
+        payload_str = base64.b64decode(message['payload'])
+        content_type = message['properties']['content_type']
+        if content_type == 'application/x-python-serialize':
+            body = pickle.loads(payload_str)
+        elif content_type == 'application/json':
+            body = json.loads(payload_str)
         else:
             raise NotImplementedError(
                 'No decode logic for messages of type %s yet' %
-                header.content_type)
+                content_type)
         task_ids.append(body['id'])
 
     return task_ids
@@ -107,14 +113,17 @@ def extract_task_ids(inspect_map):
                 yield task['id']
 
 
-def get_task_ids_map(task_types, mq_channel, celery):
+def get_task_ids_map(task_types, http_conn_params, celery):
     """
     Get a list of task ids from Celery and RabbitMQ
 
-    :param task_types: A list of tasks to retrieve. Can be any subset of the
-                       following: ['active', 'reserved', 'queued']
-    :param mq_channel: The pika.channel.Channel object to get queued tasks with
-    :param celery: The celery object to inspect the celery tasks with
+    :param task_types:
+        A list of tasks to retrieve. Can be any subset of the following:
+        ['active', 'reserved', 'queued']
+    :param http_conn_params:
+        An instance of HttpConnectionParams
+    :param celery:
+        The celery object to inspect the celery tasks with
 
     :return: {<task_type>: [task_ids],...}
     """
@@ -128,18 +137,18 @@ def get_task_ids_map(task_types, mq_channel, celery):
         task_ids_map['reserved'] = reserved_tasks(inspect)
 
     if 'queued' in task_types:
-        task_ids_map['queued'] = queued_tasks(mq_channel, CELERY_QUEUE_NAME)
+        task_ids_map['queued'] = queued_tasks(http_conn_params)
 
     LOG.debug('Found tasks: %s', task_ids_map)
 
     return task_ids_map
 
 
-def list_task_ids(task_types, mq_channel, celery):
+def list_task_ids(task_types, http_conn_params, celery):
     """
     Prints task ids and their type
     """
-    task_ids_map = get_task_ids_map(task_types, mq_channel, celery)
+    task_ids_map = get_task_ids_map(task_types, http_conn_params, celery)
     for task_type, task_ids in task_ids_map.iteritems():
         print_task_ids(task_ids, task_type)
 
@@ -149,7 +158,7 @@ def print_task_ids(tasks, heading):
     print('* {0}\n{1}\n{2}'.format(heading, '\n'.join(tasks), divider))
 
 
-def revoke_tasks_matching_regex(task_id_regex, mq_channel, celery):
+def revoke_tasks_matching_regex(task_id_regex, http_conn_params, celery):
     """
     Revoke all tasks currently been processed or waiting to be processed whos
     id match the specified regex
@@ -157,7 +166,7 @@ def revoke_tasks_matching_regex(task_id_regex, mq_channel, celery):
     LOG.info('Revoking tasks that match regex: %s', task_id_regex)
 
     task_ids_map = get_task_ids_map(['active', 'reserved', 'queued'],
-                                    mq_channel, celery)
+                                    http_conn_params, celery)
     task_ids = list(itertools.chain.from_iterable(task_ids_map.values()))
 
     matching_task_ids = filter(
@@ -176,13 +185,6 @@ def revoke_task(task_id, celery):
     celery.control.revoke(task_id, terminate=True)
 
 
-def get_mq_channel(hostname, port, virtual_host):
-    conn_params = pika.ConnectionParameters(host=hostname, port=port,
-                                            virtual_host=virtual_host)
-    conn = pika.BlockingConnection(conn_params)
-    return conn.channel()
-
-
 def get_celery_connection(hostname, port, virtual_host):
     broker_url = 'amqp://{0}:{1}/{2}'.format(hostname, port, virtual_host)
     return Celery(broker=broker_url)
@@ -194,23 +196,29 @@ def main(args):
         return 0
 
     hostname = args['--hostname']
-    port = int(args['--port'])
+    amqp_port = int(args['--amqp-port'])
+    api_port = int(args['--api-port'])
     virtual_host = args['--virtual-host']
+    username = args['--username']
+    password = args['--password']
 
-    mq_channel = get_mq_channel(hostname, port, virtual_host)
-    celery = get_celery_connection(hostname, port, virtual_host)
+    http_conn_params = HttpConnectionParams(
+        hostname, api_port, virtual_host, CELERY_QUEUE_NAME, username,
+        password)
+
+    celery = get_celery_connection(hostname, amqp_port, virtual_host)
 
     if args['list']:
         task_types = ['active', 'reserved', 'queued']
         if not args['all']:
             task_types = [task_type for task_type in task_types
                           if args[task_type]]
-        list_task_ids(task_types, mq_channel, celery)
+        list_task_ids(task_types, http_conn_params, celery)
     elif args['revoke']:
         task_id_regex = args.get('--regex')
         if task_id_regex:
             revoked_tasks = revoke_tasks_matching_regex(task_id_regex,
-                                                        mq_channel, celery)
+                                                        http_conn_params, celery)
             if revoked_tasks:
                 print('Revoked the following tasks:\n{0}'.format(
                     '\n'.join(revoked_tasks)))
